magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2

# ``magneticalc`.`QtWidgets2`.`QTextBrowser2`.`QTextBrowser2``

class documentation

`class QTextBrowser2(QTextBrowser):`

Constructor: `QTextBrowser2(html)`

View In Hierarchy

QTextBrowser2 class.

Method | `__init__` | Initializes QTextBrowser2.
Method | `fit_to_contents` | Fit to contents.

def __init__(self, html: `str | None` = None):

Initializes QTextBrowser2.

Parameters
html: `str | None` | HTML

def fit_to_contents(self):

Fit to contents.